==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/block/flower/functional/BellethornBlockEntity.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.block.flower.functional;

import vazkii.botania.api.block_entity.FunctionalFlowerBlockEntity;
import vazkii.botania.api.block_entity.RadiusDescriptor;
import vazkii.botania.common.block.BotaniaFlowerBlocks;

import java.util.List;
import java.util.function.Predicate;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1640;
import net.minecraft.class_1657;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_2591;
import net.minecraft.class_2680;

public class BellethornBlockEntity extends FunctionalFlowerBlockEntity {
	public static final int RANGE = 6;
	public static final int RANGE_MINI = 1;

	protected BellethornBlockEntity(class_2591<?> type, class_2338 pos, class_2680 state) {
		super(type, pos, state);
	}

	public BellethornBlockEntity(class_2338 pos, class_2680 state) {
		this(BotaniaFlowerBlocks.BELLETHORNE, pos, state);
	}

	@Override
	public int getColor() {
		return 0xBA3421;
	}

	@Override
	public int getMaxMana() {
		return 1000;
	}

	@Override
	public void tickFlower() {
		super.tickFlower();

		if (method_10997().field_9236 || redstoneSignal > 0) {
			return;
		}

		if (ticksExisted % 200 == 0) {
			sync();
		}

		final int manaToUse = getManaCost();

		if (ticksExisted % 5 == 0) {
			int range = getRange();
			List<class_1309> entities = method_10997().method_8390(class_1309.class, new class_238(getEffectivePos().method_10069(-range, -range, -range), getEffectivePos().method_10069(range + 1, range + 1, range + 1)), getSelector());

			for (class_1309 entity : entities) {
				if (getMana() < manaToUse) {
					break;
				}
				if (entity.field_6235 == 0) {
					int dmg = 4;
					if (entity instanceof class_1640) {
						dmg = 20;
					}

					entity.method_5643(class_1282.field_5846, dmg);
					addMana(-manaToUse);
				}
			}
		}
	}

	@Override
	public boolean acceptsRedstone() {
		return true;
	}

	public int getManaCost() {
		return 24;
	}

	public int getRange() {
		return RANGE;
	}

	public Predicate<class_1297> getSelector() {
		return entity -> !(entity instanceof class_1657);
	}

	@Override
	public RadiusDescriptor getRadius() {
		return RadiusDescriptor.Rectangle.square(getEffectivePos(), getRange());
	}

	public static class Mini extends BellethornBlockEntity {
		public Mini(class_2338 pos, class_2680 state) {
			super(BotaniaFlowerBlocks.BELLETHORNE_CHIBI, pos, state);
		}

		@Override
		public int getRange() {
			return RANGE_MINI;
		}
	}

}

==> Botania-1.20.1-451-FABRIC-20251024.183033-20-sources.jar: vazkii/botania/common/block/flower/functional/BellethornBlockEntity.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.block.flower.functional;

import vazkii.botania.api.block_entity.FunctionalFlowerBlockEntity;
import vazkii.botania.api.block_entity.RadiusDescriptor;
import vazkii.botania.common.block.BotaniaFlowerBlocks;

import java.util.List;
import java.util.function.Predicate;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1640;
import net.minecraft.class_1657;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_2591;
import net.minecraft.class_2680;

public class BellethornBlockEntity extends FunctionalFlowerBlockEntity {
	public static final int RANGE = 6;
	public static final int RANGE_MINI = 1;

	protected BellethornBlockEntity(class_2591<?> type, class_2338 pos, class_2680 state) {
		super(type, pos, state);
	}

	public BellethornBlockEntity(class_2338 pos, class_2680 state) {
		this(BotaniaFlowerBlocks.BELLETHORNE, pos, state);
	}

	@Override
	public int getColor() {
		return 0xBA3421;
	}

	@Override
	public int getMaxMana() {
		return 1000;
	}

	@Override
	public void tickFlower() {
		super.tickFlower();

		if (method_10997().field_9236 || redstoneSignal > 0) {
			return;
		}

		if (ticksExisted % 200 == 0) {
			sync();
		}

		final int manaToUse = getManaCost();

		if (ticksExisted % 5 == 0) {
			int range = getRange();
			List<class_1309> entities = method_10997().method_8390(class_1309.class, new class_238(getEffectivePos().method_10069(-range, -range, -range), getEffectivePos().method_10069(range + 1, range + 1, range + 1)), getSelector());

			for (class_1309 entity : entities) {
				if (getMana() < manaToUse) {
					break;
				}
				if (entity.field_6235 == 0) {
					int dmg = 4;
					if (entity instanceof class_1640) {
						dmg = 20;
					}

					entity.method_5643(method_10997().method_48963().method_48831(), dmg);
					addMana(-manaToUse);
				}
			}
		}
	}

	@Override
	public boolean acceptsRedstone() {
		return true;
	}

	public int getManaCost() {
		return 24;
	}

	public int getRange() {
		return RANGE;
	}

	public Predicate<class_1297> getSelector() {
		return entity -> !(entity instanceof class_1657);
	}

	@Override
	public RadiusDescriptor getRadius() {
		return RadiusDescriptor.Rectangle.square(getEffectivePos(), getRange());
	}

	public static class Mini extends BellethornBlockEntity {
		public Mini(class_2338 pos, class_2680 state) {
			super(BotaniaFlowerBlocks.BELLETHORNE_CHIBI, pos, state);
		}

		@Override
		public int getRange() {
			return RANGE_MINI;
		}
	}

}
